SklearnEvaluator
================

.. currentmodule:: pykeen.evaluation

.. autoclass:: SklearnEvaluator
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~SklearnEvaluator.finalize
      ~SklearnEvaluator.process_head_scores_
      ~SklearnEvaluator.process_tail_scores_

   .. rubric:: Methods Documentation

   .. automethod:: finalize
   .. automethod:: process_head_scores_
   .. automethod:: process_tail_scores_
